@@ -49,7 +49,7 @@ class DBMonitorProvider(object):
         if len(instances) == 1:
             flag_cluster_str = 'false'
             flag_cluster = False
-            machine = instances[0].address
+            machine = instances[0].hostname
         else:
             flag_cluster_str = 'true'
             flag_cluster = True
@@ -62,7 +62,7 @@ class DBMonitorProvider(object):
         else:
             LOG.error('Not implemented engine type')
             raise NotImplementedError()
-        dns, port = databaseinfra.endpoint.split(':')
+        dns, port = databaseinfra.endpoint_dns.split(':')
         self.auth(environment)
         
         tipo = EnvironmentAttr.objects.get(dbaas_environment=environment).dbmonitor_environment
@@ -117,7 +117,7 @@ class DBMonitorProvider(object):
                     'database_id': dbmonitor_infraid,
                     'nome': databaseinfra.name[:48]+ '-' + str(cont),
                     'maquina': instance.hostname,
-                    'dns': instance.address,
+                    'dns': instance.dns,
                     'porta': instance.port,
                     'ativo': 'true',
                     }
